clear;clc;close all;
load('local_out/mooring_fianl.mat');
cd figures
scrsz = get(groot,'ScreenSize');

%%% velocity at 25m , s9-36 -> row:13 ; s2 -> row:12 ; data -> row:12
for n = 1:3
    figure('Position',[1 scrsz(4)/2 scrsz(3)/2 scrsz(4)/2])
    subplot(2,1,1);hold on;
    plot(mooring_final.Time,mooring_final.d.u{n}(12,:),'k');
    plot(mooring_final.Time,mooring_final.s2.u{n}(12,:));
    plot(mooring_final.Time,mooring_final.s9.u{n}(13,:));
    plot(mooring_final.Time,mooring_final.s36.u{n}(13,:));
    datetick('x','mmm');legend('data','2km','9km','36km');ylim([-0.15 0.15])
    title(sprintf('mooring %s at 25m depth ',mooring_final.name{n}(7)))
    ylabel('eastward velocity ms^-^1')
    subplot(2,1,2);hold on;
    plot(mooring_final.Time,mooring_final.d.v{n}(12,:),'k');
    plot(mooring_final.Time,mooring_final.s2.v{n}(12,:));
    plot(mooring_final.Time,mooring_final.s9.v{n}(13,:));
    plot(mooring_final.Time,mooring_final.s36.v{n}(13,:));
    datetick('x','mmm');legend('data','2km','9km','36km');ylim([-0.15 0.15])
        title(sprintf('mooring %s V',mooring_final.name{n}(7)))
    ylabel('northward velocity ms^-^1')
        print(gcf,'-djpeg','-r 640',sprintf('25m velocites %s',mooring_final.name{n}(7)))
    
    
end

%%% finding correlation
for n= 1:3
    
    d_u{n} =  mooring_final.d.u{n}(12,:);
    d_v{n} =  mooring_final.d.v{n}(12,:);
    s2_u{n} = mooring_final.s2.u{n}(12,:);
    s2_v{n} = mooring_final.s2.v{n}(12,:);
    s9_u{n} = mooring_final.s9.u{n}(13,:);
    s9_v{n} = mooring_final.s9.v{n}(13,:);
    s36_u{n} = mooring_final.s36.u{n}(13,:);
    s36_v{n} = mooring_final.s36.v{n}(13,:);
    
    rmse_2u{n} = sqrt(nansum(d_u{n} - s2_u{n}).^2)./(length(~isnan(d_u{n}))-1);
    rmse_2v{n} = sqrt(nansum(d_v{n} - s2_v{n}).^2)./(length(~isnan(d_v{n}))-1);
    rmse_0u{n} = sqrt(nansum(d_u{n}.^2))./(length(~isnan(d_u{n}))-1);
    rmse_0v{n} = sqrt(nansum(d_v{n}.^2))./(length(~isnan(d_v{n}))-1);
    rmse_36u{n} = sqrt(nansum(d_u{n} - s36_u{n}).^2)./(length(~isnan(d_u{n}))-1);
    rmse_36v{n} = sqrt(nansum(d_v{n} - s36_v{n}).^2)./(length(~isnan(d_v{n}))-1);
    rmse_9u{n} = sqrt(nansum(d_u{n} - s9_u{n}).^2)./(length(~isnan(d_u{n}))-1);
    rmse_9v{n} = sqrt(nansum(d_v{n} - s9_v{n}).^2)./(length(~isnan(d_v{n}))-1);
    
    d_sp{n} = sqrt(d_u{n}.^2 + d_v{n}.^2);
    s2_sp{n} = sqrt(s2_u{n}.^2 + s2_v{n}.^2);
    s9_sp{n} = sqrt(s9_u{n}.^2 + s9_v{n}.^2);
    s36_sp{n} = sqrt(s36_u{n}.^2 + s36_v{n}.^2);
    
    rmse_2sp{n} = sqrt(nansum(d_sp{n} - s2_sp{n}).^2)./(length(~isnan(d_sp{n}))-1);    
    rmse_9sp{n} = sqrt(nansum(d_sp{n} - s9_sp{n}).^2)./(length(~isnan(d_sp{n}))-1);    
    rmse_36sp{n} = sqrt(nansum(d_sp{n} - s36_sp{n}).^2)./(length(~isnan(d_sp{n}))-1);    
    rmse_0sp{n} = sqrt(nansum(d_sp{n}).^2)./(length(~isnan(d_sp{n}))-1);    
 
    
    s2_u{n}(isnan(d_u{n})) = 0;
    s2_v{n}(isnan(d_v{n})) = 0;
    s9_u{n}(isnan(d_u{n})) = 0;
    s9_v{n}(isnan(d_v{n})) = 0;
    s36_u{n}(isnan(d_u{n})) = 0;
    s36_v{n}(isnan(d_v{n})) = 0;
    d_u{n}(isnan(d_u{n})) = 0;
    d_v{n}(isnan(d_v{n})) = 0;
    
    corr_u_s2{n}=corrcoef(d_u{n},s2_u{n});
    corr_v_s2{n}=corrcoef(d_u{n},s2_v{n});
    corr_u_s9{n}=corrcoef(d_u{n},s9_u{n});
    corr_v_s9{n}=corrcoef(d_u{n},s9_v{n});
    corr_u_s36{n}=corrcoef(d_u{n},s36_u{n});
    corr_v_s36{n}=corrcoef(d_u{n},s36_u{n});
      
end

s2_rmse_mean_u = mean([rmse_2u{1},rmse_2u{2},rmse_2u{3}])*100;
s2_rmse_mean_v = mean([rmse_2v{1},rmse_2v{2},rmse_2v{3}])*100;
s9_rmse_mean_u = mean([rmse_9u{1},rmse_9u{2},rmse_9u{3}])*100;
s9_rmse_mean_v = mean([rmse_9v{1},rmse_9v{2},rmse_9v{3}])*100;
s36_rmse_mean_u = mean([rmse_36u{1},rmse_36u{2},rmse_36u{3}])*100;
s36_rmse_mean_v = mean([rmse_36v{1},rmse_36v{2},rmse_36v{3}])*100;
s0_rmse_mean_u = mean([rmse_0u{1},rmse_0u{2},rmse_0u{3}])*100;
s0_rmse_mean_v = mean([rmse_0v{1},rmse_0v{2},rmse_0v{3}])*100;

s2_rmse_mean_sp = mean([rmse_2sp{1},rmse_2sp{2},rmse_2sp{3}])*100;
s9_rmse_mean_sp = mean([rmse_9sp{1},rmse_9sp{2},rmse_9sp{3}])*100;
s36_rmse_mean_sp = mean([rmse_36sp{1},rmse_36sp{2},rmse_36sp{3}])*100;
s0_rmse_mean_sp = mean([rmse_0sp{1},rmse_0sp{2},rmse_0sp{3}])*100;

s2_rmse_u_ratio = s2_rmse_mean_u/s0_rmse_mean_u;
s9_rmse_u_ratio = s9_rmse_mean_u/s0_rmse_mean_u;
s36_rmse_u_ratio = s36_rmse_mean_u/s0_rmse_mean_u;
s2_rmse_v_ratio = s2_rmse_mean_v/s0_rmse_mean_v;
s9_rmse_v_ratio = s9_rmse_mean_v/s0_rmse_mean_v;
s36_rmse_v_ratio = s36_rmse_mean_v/s0_rmse_mean_v;

s2_rmse_spd_ratio = s2_rmse_mean_sp/s0_rmse_mean_sp;
s9_rmse_spd_ratio = s9_rmse_mean_sp/s0_rmse_mean_sp;
s36_rmse_spd_ratio = s36_rmse_mean_sp/s0_rmse_mean_sp;
display('normlized RMSE by 0 velocity over ~1000 samples')
display(sprintf('2km  u : %.1f  v : %.1f',s2_rmse_u_ratio,s2_rmse_v_ratio))
display(sprintf('9km  u : %.1f  v : %.1f',s9_rmse_u_ratio,s9_rmse_v_ratio))
display(sprintf('36km u : %.1f  v : %.1f',s36_rmse_u_ratio,s36_rmse_v_ratio))
display(sprintf('36km speed : %.1f -- 9km speed : %.1f -- 2km speed : %.1f',s36_rmse_spd_ratio,s9_rmse_spd_ratio,s2_rmse_spd_ratio))


